{% extends "cookie_consent/base.html" %}

{% block body %}
  <h1>Cookies</h1>

  <p>
    This is a list of the categories of cookies used in our website and why we use them.
  </p>

  {% for cookie_group in object_list  %}
    {% include "cookie_consent/_cookie_group.html" %}
  {% endfor %}

{% endblock %}
